Documentation
¶
Overview ¶
Package options holds the option settings for a single graph generation.
Index ¶
Constants ¶
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type NodeOptions ¶ added in v0.8.0
type NodeOptions struct {
App string
Namespace string
Service string
Version string
Workload string
}
NodeOptions are those that apply only to node-detail graphs
type Options ¶
type Options struct {
AccessibleNamespaces map[string]time.Time
Appenders []appender.Appender
IncludeIstio bool // include istio-system services. Ignored for istio-system ns. Default false.
InjectServiceNodes bool // inject destination service nodes between source and destination nodes.
Namespaces map[string]graph.NamespaceInfo
Vendor string
NodeOptions
VendorOptions
}
Options are all supported graph generation options.
func NewOptions ¶
func (*Options) GetGraphKind ¶ added in v0.9.1
GetGraphKind will return the kind of graph represented by the options.
Click to show internal directories.
Click to hide internal directories.